#[non_exhaustive]pub enum AsyncControlError {
TimedOut,
Cancelled,
}Expand description
Error returned by timeout, deadline, cancellation, and shutdown helpers.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
TimedOut
The wrapped operation did not complete before its timeout or deadline.
Cancelled
The caller-owned cancellation or shutdown signal completed first.